function convFTCS
% convFTCS  Convergence of FTCS on a series of finer spatial meshes

% --- Set constants to be consistent with demoFTCS
alfa = 0.1;  L = 1;  tmax=2;   rsafe = 0.49999;  %  stable r<0.5

% --- Specify nx and compute nt consistent with stability limit
nx = [8 16 32 64 128 256];    dx = L./(nx-1);
nt = ceil( 1 + alfa*tmax*((nx-1).^2)/(rsafe*L^2) );

% --- Loop over mesh sizes, store error and compute order of scheme
fprintf('\n    nx     nt     error     E(j)/E(j-1)    p\n');
er = NaN;  p = 0;  e = zeros(length(nx),1);
for j=1:length(nx)
  e(j) = demoFTCS(nx(j),nt(j));
  if j>1
    er = e(j)/e(j-1);  p = log(er)/log(nx(j-1)/nx(j));
  end
  fprintf(' %5d  %5d  %11.3e  %8.4f  %8.4f\n',nx(j),nt(j),e(j),er,p);
end

% --- Plot measured error and predicted (ideal) error
jmid = fix(length(e)/2);   % jmid is handy point to define ideal curve
eideal = e(jmid)*(dx/dx(jmid)).^2;
loglog(dx,e,'o',dx,eideal,'r--');
legend('FTCS','ideal','Location','northeast');
xlabel('\Delta x');   ylabel('E(n_x,n_y)');

end