function [e,f] = tridiagLU(a,b,c)
% tridiagLU  Obtain the LU factorization of a tridiagonal matrix
%
% Synopsis:  [e,f] = tridiag(a,b,c)
%
% Input:  a,b,c = vectors defining the tridiagonal matrix.  a is the main
%                 diagonal, b is the superdiagonal, c is subdiagonal
%
% Output:  e,f = vectors defining the L and U factors of the tridiagonal
%                matrix.  L has the e vector on the subdiagonal and ones on
%                its main diagonal.  U has the f vector on its main
%                diagonal and the b vector on its superdiagonal

% --- Preallocate variables
n = length(a);  e = zeros(n,1);  f = e;

% --- Elimination phase: compute e and f
f(1) = a(1);
for i=2:n
	e(i) = c(i)/f(i-1);
	f(i) = a(i) - e(i)*b(i-1);
end

end