function x = tridiagLUsolve(e,f,b,d,x)
% tridiagLUsolve  Solve (LU)*x = d given the LU factors of a tridiagonal
%                 matrix
%
% Synopsis:  v = tridiagLUsolve(e,f,b,d)
%            v = tridiagLUsolve(e,f,b,d,x)
%
% Input:  e = vector containing subdiagonal of L. (main diagonal is ones)
%         f,b = vectors containing main diagonal and superdiagonal of U.
%         d = right hand side vector of the system of equations
%         x = (optional) vector to be used to store the solution.  If x
%             is not provided, it is created.  If x is provided it is reused.
%
% Output: x = solution vector

n = length(d);
if nargin<5,  x = zeros(n,1);  end

% --- Forward substitution: solve L*y = d.  Use x instead of y
x(1) = d(1);
for i=2:n
  x(i) = d(i) - e(i)*x(i-1);
end
% --- Backward substitution: solve U*x = y.  y is stored in x to start of loop
x(n) = x(n)/f(n);
for i=n-1:-1:1
  x(i) = (x(i) - b(i)*x(i+1))/f(i);
end

end