function x = tridiagSolve(a,b,c,d)
% tridiagSolve  Solve A*x = d when A is a diagonally dominant and tridiagonal
%
% Synopsis:  x = tridiagSolve(a,b,c,d)
%
% Input:  a,b,c = vectors defining the tridiagonal matrix.  a is the main
%                 diagonal, b is the superdiagonal, c is subdiagonal
%         d = right hand side vector of the system of equations
%
% Output: x = solution vector

% --- Preallocate variables
n = size(d,1);  x = zeros(n,1);  f = x;

% --- Elimination and forward substitution to compute y, stored in x
f(1) = a(1);
x(1) = d(1);
for i=2:n
  e = c(i)/f(i-1);
	f(i) = a(i) - e*b(i-1);
  x(i) = d(i) - e*x(i-1);
end
% --- Backward substitution: solve U*x = y.  y is stored in x at start of loop
x(n) = x(n)/f(n);
for i=n-1:-1:1
  x(i) = ( x(i) - b(i)*x(i+1) )/f(i);
end

end